from make87_messages_ros2.jazzy.autoware_perception_msgs.msg import detected_object_kinematics_pb2 as _detected_object_kinematics_pb2
from make87_messages_ros2.jazzy.autoware_perception_msgs.msg import object_classification_pb2 as _object_classification_pb2
from make87_messages_ros2.jazzy.autoware_perception_msgs.msg import shape_pb2 as _shape_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DetectedObject(_message.Message):
    __slots__ = ("existence_probability", "classification", "kinematics", "shape")
    EXISTENCE_PROBABILITY_FIELD_NUMBER: _ClassVar[int]
    CLASSIFICATION_FIELD_NUMBER: _ClassVar[int]
    KINEMATICS_FIELD_NUMBER: _ClassVar[int]
    SHAPE_FIELD_NUMBER: _ClassVar[int]
    existence_probability: float
    classification: _containers.RepeatedCompositeFieldContainer[_object_classification_pb2.ObjectClassification]
    kinematics: _detected_object_kinematics_pb2.DetectedObjectKinematics
    shape: _shape_pb2.Shape
    def __init__(self, existence_probability: _Optional[float] = ..., classification: _Optional[_Iterable[_Union[_object_classification_pb2.ObjectClassification, _Mapping]]] = ..., kinematics: _Optional[_Union[_detected_object_kinematics_pb2.DetectedObjectKinematics, _Mapping]] = ..., shape: _Optional[_Union[_shape_pb2.Shape, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/controller_manager_msgs/msg/controller_state.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.controller_manager_msgs.msg import chain_connection_pb2 as make87__messages__ros2_dot_jazzy_dot_controller__manager__msgs_dot_msg_dot_chain__connection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMmake87_messages_ros2/jazzy/controller_manager_msgs/msg/controller_state.proto\x12\x36make87_messages_ros2.jazzy.controller_manager_msgs.msg\x1aMmake87_messages_ros2/jazzy/controller_manager_msgs/msg/chain_connection.proto\"\xef\x02\n\x0f\x43ontrollerState\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x1a\n\x12\x63laimed_interfaces\x18\x04 \x03(\t\x12#\n\x1brequired_command_interfaces\x18\x05 \x03(\t\x12!\n\x19required_state_interfaces\x18\x06 \x03(\t\x12\x14\n\x0cis_chainable\x18\x07 \x01(\x08\x12\x12\n\nis_chained\x18\x08 \x01(\x08\x12!\n\x19\x65xported_state_interfaces\x18\t \x03(\t\x12\x1c\n\x14reference_interfaces\x18\n \x03(\t\x12\x62\n\x11\x63hain_connections\x18\x0b \x03(\x0b\x32G.make87_messages_ros2.jazzy.controller_manager_msgs.msg.ChainConnectionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.controller_manager_msgs.msg.controller_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CONTROLLERSTATE']._serialized_start=217
  _globals['_CONTROLLERSTATE']._serialized_end=584
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rc_reason_msgs/srv/get_base_plane_calibration.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.rolling.rc_common_msgs.msg import return_code_pb2 as make87__messages__ros2_dot_rolling_dot_rc__common__msgs_dot_msg_dot_return__code__pb2
from make87_messages_ros2.rolling.shape_msgs.msg import plane_pb2 as make87__messages__ros2_dot_rolling_dot_shape__msgs_dot_msg_dot_plane__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/rolling/rc_reason_msgs/srv/get_base_plane_calibration.proto\x12/make87_messages_ros2.rolling.rc_reason_msgs.srv\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\x1a\x41make87_messages_ros2/rolling/rc_common_msgs/msg/return_code.proto\x1a\x37make87_messages_ros2/rolling/shape_msgs/msg/plane.proto\"~\n\x1eGetBasePlaneCalibrationRequest\x12\x12\n\npose_frame\x18\x01 \x01(\t\x12H\n\nrobot_pose\x18\x02 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Pose\"\xca\x01\n\x1fGetBasePlaneCalibrationResponse\x12\x12\n\npose_frame\x18\x01 \x01(\t\x12\x41\n\x05plane\x18\x02 \x01(\x0b\x32\x32.make87_messages_ros2.rolling.shape_msgs.msg.Plane\x12P\n\x0breturn_code\x18\x03 \x01(\x0b\x32;.make87_messages_ros2.rolling.rc_common_msgs.msg.ReturnCodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rc_reason_msgs.srv.get_base_plane_calibration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETBASEPLANECALIBRATIONREQUEST']._serialized_start=316
  _globals['_GETBASEPLANECALIBRATIONREQUEST']._serialized_end=442
  _globals['_GETBASEPLANECALIBRATIONRESPONSE']._serialized_start=445
  _globals['_GETBASEPLANECALIBRATIONRESPONSE']._serialized_end=647
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.rmf_traffic_msgs.msg import negotiation_status_pb2 as _negotiation_status_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NegotiationStatuses(_message.Message):
    __slots__ = ("negotiations",)
    NEGOTIATIONS_FIELD_NUMBER: _ClassVar[int]
    negotiations: _containers.RepeatedCompositeFieldContainer[_negotiation_status_pb2.NegotiationStatus]
    def __init__(self, negotiations: _Optional[_Iterable[_Union[_negotiation_status_pb2.NegotiationStatus, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TestMultipleRequestFieldsRequest(_message.Message):
    __slots__ = ("header", "int_value", "float_value", "string", "bool_value")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    INT_VALUE_FIELD_NUMBER: _ClassVar[int]
    FLOAT_VALUE_FIELD_NUMBER: _ClassVar[int]
    STRING_FIELD_NUMBER: _ClassVar[int]
    BOOL_VALUE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    int_value: int
    float_value: float
    string: str
    bool_value: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., int_value: _Optional[int] = ..., float_value: _Optional[float] = ..., string: _Optional[str] = ..., bool_value: bool = ...) -> None: ...

class TestMultipleRequestFieldsResponse(_message.Message):
    __slots__ = ("header",)
    HEADER_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ApiServiceRequest(_message.Message):
    __slots__ = ("json_msg",)
    JSON_MSG_FIELD_NUMBER: _ClassVar[int]
    json_msg: str
    def __init__(self, json_msg: _Optional[str] = ...) -> None: ...

class ApiServiceResponse(_message.Message):
    __slots__ = ("json_msg",)
    JSON_MSG_FIELD_NUMBER: _ClassVar[int]
    json_msg: str
    def __init__(self, json_msg: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Defaults(_message.Message):
    __slots__ = ("bool_value", "byte_value", "char_value", "float32_value", "float64_value", "int8_value", "uint8_value", "int16_value", "uint16_value", "int32_value", "uint32_value", "int64_value", "uint64_value")
    BOOL_VALUE_FIELD_NUMBER: _ClassVar[int]
    BYTE_VALUE_FIELD_NUMBER: _ClassVar[int]
    CHAR_VALUE_FIELD_NUMBER: _ClassVar[int]
    FLOAT32_VALUE_FIELD_NUMBER: _ClassVar[int]
    FLOAT64_VALUE_FIELD_NUMBER: _ClassVar[int]
    INT8_VALUE_FIELD_NUMBER: _ClassVar[int]
    UINT8_VALUE_FIELD_NUMBER: _ClassVar[int]
    INT16_VALUE_FIELD_NUMBER: _ClassVar[int]
    UINT16_VALUE_FIELD_NUMBER: _ClassVar[int]
    INT32_VALUE_FIELD_NUMBER: _ClassVar[int]
    UINT32_VALUE_FIELD_NUMBER: _ClassVar[int]
    INT64_VALUE_FIELD_NUMBER: _ClassVar[int]
    UINT64_VALUE_FIELD_NUMBER: _ClassVar[int]
    bool_value: bool
    byte_value: int
    char_value: int
    float32_value: float
    float64_value: float
    int8_value: int
    uint8_value: int
    int16_value: int
    uint16_value: int
    int32_value: int
    uint32_value: int
    int64_value: int
    uint64_value: int
    def __init__(self, bool_value: bool = ..., byte_value: _Optional[int] = ..., char_value: _Optional[int] = ..., float32_value: _Optional[float] = ..., float64_value: _Optional[float] = ..., int8_value: _Optional[int] = ..., uint8_value: _Optional[int] = ..., int16_value: _Optional[int] = ..., uint16_value: _Optional[int] = ..., int32_value: _Optional[int] = ..., uint32_value: _Optional[int] = ..., int64_value: _Optional[int] = ..., uint64_value: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.smacc2_msgs.msg import smacc_transition_log_entry_pb2 as _smacc_transition_log_entry_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SmaccGetTransitionHistoryRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class SmaccGetTransitionHistoryResponse(_message.Message):
    __slots__ = ("history",)
    HISTORY_FIELD_NUMBER: _ClassVar[int]
    history: _containers.RepeatedCompositeFieldContainer[_smacc_transition_log_entry_pb2.SmaccTransitionLogEntry]
    def __init__(self, history: _Optional[_Iterable[_Union[_smacc_transition_log_entry_pb2.SmaccTransitionLogEntry, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ublox_msgs/msg/mon_ver.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.ublox_msgs.msg import mon_ver_extension_pb2 as make87__messages__ros2_dot_rolling_dot_ublox__msgs_dot_msg_dot_mon__ver__extension__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/rolling/ublox_msgs/msg/mon_ver.proto\x12+make87_messages_ros2.rolling.ublox_msgs.msg\x1a\x43make87_messages_ros2/rolling/ublox_msgs/msg/mon_ver_extension.proto\"\x81\x01\n\x06MonVER\x12\x12\n\nsw_version\x18\x01 \x03(\x05\x12\x12\n\nhw_version\x18\x02 \x03(\x05\x12O\n\textension\x18\x03 \x03(\x0b\x32<.make87_messages_ros2.rolling.ublox_msgs.msg.MonVERExtensionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ublox_msgs.msg.mon_ver_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MONVER']._serialized_start=176
  _globals['_MONVER']._serialized_end=305
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/cartographer_ros_msgs/msg/landmark_entry.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/jazzy/cartographer_ros_msgs/msg/landmark_entry.proto\x12\x34make87_messages_ros2.jazzy.cartographer_ros_msgs.msg\x1a\x37make87_messages_ros2/jazzy/geometry_msgs/msg/pose.proto\"\xae\x01\n\rLandmarkEntry\x12\n\n\x02id\x18\x01 \x01(\t\x12\\\n tracking_from_landmark_transform\x18\x02 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.geometry_msgs.msg.Pose\x12\x1a\n\x12translation_weight\x18\x03 \x01(\x01\x12\x17\n\x0frotation_weight\x18\x04 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.cartographer_ros_msgs.msg.landmark_entry_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LANDMARKENTRY']._serialized_start=189
  _globals['_LANDMARKENTRY']._serialized_end=363
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.visualization_msgs.msg import interactive_marker_pb2 as _interactive_marker_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetInteractiveMarkersRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetInteractiveMarkersResponse(_message.Message):
    __slots__ = ("sequence_number", "markers")
    SEQUENCE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    MARKERS_FIELD_NUMBER: _ClassVar[int]
    sequence_number: int
    markers: _containers.RepeatedCompositeFieldContainer[_interactive_marker_pb2.InteractiveMarker]
    def __init__(self, sequence_number: _Optional[int] = ..., markers: _Optional[_Iterable[_Union[_interactive_marker_pb2.InteractiveMarker, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from make87_messages_ros2.jazzy.ublox_ubx_msgs.msg import carr_soln_pb2 as _carr_soln_pb2
from make87_messages_ros2.jazzy.ublox_ubx_msgs.msg import gps_fix_pb2 as _gps_fix_pb2
from make87_messages_ros2.jazzy.ublox_ubx_msgs.msg import psmpvt_pb2 as _psmpvt_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UBXNavPVT(_message.Message):
    __slots__ = ("header", "itow", "year", "month", "day", "hour", "min", "sec", "valid_date", "valid_time", "fully_resolved", "valid_mag", "t_acc", "nano", "gps_fix", "gnss_fix_ok", "diff_soln", "psm", "head_veh_valid", "carr_soln", "confirmed_avail", "confirmed_date", "confirmed_time", "num_sv", "lon", "lat", "height", "hmsl", "h_acc", "v_acc", "vel_n", "vel_e", "vel_d", "g_speed", "head_mot", "s_acc", "head_acc", "p_dop", "invalid_llh", "head_veh", "mag_dec", "mag_acc")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ITOW_FIELD_NUMBER: _ClassVar[int]
    YEAR_FIELD_NUMBER: _ClassVar[int]
    MONTH_FIELD_NUMBER: _ClassVar[int]
    DAY_FIELD_NUMBER: _ClassVar[int]
    HOUR_FIELD_NUMBER: _ClassVar[int]
    MIN_FIELD_NUMBER: _ClassVar[int]
    SEC_FIELD_NUMBER: _ClassVar[int]
    VALID_DATE_FIELD_NUMBER: _ClassVar[int]
    VALID_TIME_FIELD_NUMBER: _ClassVar[int]
    FULLY_RESOLVED_FIELD_NUMBER: _ClassVar[int]
    VALID_MAG_FIELD_NUMBER: _ClassVar[int]
    T_ACC_FIELD_NUMBER: _ClassVar[int]
    NANO_FIELD_NUMBER: _ClassVar[int]
    GPS_FIX_FIELD_NUMBER: _ClassVar[int]
    GNSS_FIX_OK_FIELD_NUMBER: _ClassVar[int]
    DIFF_SOLN_FIELD_NUMBER: _ClassVar[int]
    PSM_FIELD_NUMBER: _ClassVar[int]
    HEAD_VEH_VALID_FIELD_NUMBER: _ClassVar[int]
    CARR_SOLN_FIELD_NUMBER: _ClassVar[int]
    CONFIRMED_AVAIL_FIELD_NUMBER: _ClassVar[int]
    CONFIRMED_DATE_FIELD_NUMBER: _ClassVar[int]
    CONFIRMED_TIME_FIELD_NUMBER: _ClassVar[int]
    NUM_SV_FIELD_NUMBER: _ClassVar[int]
    LON_FIELD_NUMBER: _ClassVar[int]
    LAT_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    HMSL_FIELD_NUMBER: _ClassVar[int]
    H_ACC_FIELD_NUMBER: _ClassVar[int]
    V_ACC_FIELD_NUMBER: _ClassVar[int]
    VEL_N_FIELD_NUMBER: _ClassVar[int]
    VEL_E_FIELD_NUMBER: _ClassVar[int]
    VEL_D_FIELD_NUMBER: _ClassVar[int]
    G_SPEED_FIELD_NUMBER: _ClassVar[int]
    HEAD_MOT_FIELD_NUMBER: _ClassVar[int]
    S_ACC_FIELD_NUMBER: _ClassVar[int]
    HEAD_ACC_FIELD_NUMBER: _ClassVar[int]
    P_DOP_FIELD_NUMBER: _ClassVar[int]
    INVALID_LLH_FIELD_NUMBER: _ClassVar[int]
    HEAD_VEH_FIELD_NUMBER: _ClassVar[int]
    MAG_DEC_FIELD_NUMBER: _ClassVar[int]
    MAG_ACC_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    itow: int
    year: int
    month: int
    day: int
    hour: int
    min: int
    sec: int
    valid_date: bool
    valid_time: bool
    fully_resolved: bool
    valid_mag: bool
    t_acc: int
    nano: int
    gps_fix: _gps_fix_pb2.GpsFix
    gnss_fix_ok: bool
    diff_soln: bool
    psm: _psmpvt_pb2.PSMPVT
    head_veh_valid: bool
    carr_soln: _carr_soln_pb2.CarrSoln
    confirmed_avail: bool
    confirmed_date: bool
    confirmed_time: bool
    num_sv: int
    lon: int
    lat: int
    height: int
    hmsl: int
    h_acc: int
    v_acc: int
    vel_n: int
    vel_e: int
    vel_d: int
    g_speed: int
    head_mot: int
    s_acc: int
    head_acc: int
    p_dop: int
    invalid_llh: bool
    head_veh: int
    mag_dec: int
    mag_acc: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., itow: _Optional[int] = ..., year: _Optional[int] = ..., month: _Optional[int] = ..., day: _Optional[int] = ..., hour: _Optional[int] = ..., min: _Optional[int] = ..., sec: _Optional[int] = ..., valid_date: bool = ..., valid_time: bool = ..., fully_resolved: bool = ..., valid_mag: bool = ..., t_acc: _Optional[int] = ..., nano: _Optional[int] = ..., gps_fix: _Optional[_Union[_gps_fix_pb2.GpsFix, _Mapping]] = ..., gnss_fix_ok: bool = ..., diff_soln: bool = ..., psm: _Optional[_Union[_psmpvt_pb2.PSMPVT, _Mapping]] = ..., head_veh_valid: bool = ..., carr_soln: _Optional[_Union[_carr_soln_pb2.CarrSoln, _Mapping]] = ..., confirmed_avail: bool = ..., confirmed_date: bool = ..., confirmed_time: bool = ..., num_sv: _Optional[int] = ..., lon: _Optional[int] = ..., lat: _Optional[int] = ..., height: _Optional[int] = ..., hmsl: _Optional[int] = ..., h_acc: _Optional[int] = ..., v_acc: _Optional[int] = ..., vel_n: _Optional[int] = ..., vel_e: _Optional[int] = ..., vel_d: _Optional[int] = ..., g_speed: _Optional[int] = ..., head_mot: _Optional[int] = ..., s_acc: _Optional[int] = ..., head_acc: _Optional[int] = ..., p_dop: _Optional[int] = ..., invalid_llh: bool = ..., head_veh: _Optional[int] = ..., mag_dec: _Optional[int] = ..., mag_acc: _Optional[int] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class MutexGroupManualRelease(_message.Message):
    __slots__ = ("release_mutex_groups", "fleet", "robot")
    RELEASE_MUTEX_GROUPS_FIELD_NUMBER: _ClassVar[int]
    FLEET_FIELD_NUMBER: _ClassVar[int]
    ROBOT_FIELD_NUMBER: _ClassVar[int]
    release_mutex_groups: _containers.RepeatedScalarFieldContainer[str]
    fleet: str
    robot: str
    def __init__(self, release_mutex_groups: _Optional[_Iterable[str]] = ..., fleet: _Optional[str] = ..., robot: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EsrStatus3(_message.Message):
    __slots__ = ("header", "canmsg", "interface_version", "hw_version", "sw_version_host", "serial_num", "sw_version_pld")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CANMSG_FIELD_NUMBER: _ClassVar[int]
    INTERFACE_VERSION_FIELD_NUMBER: _ClassVar[int]
    HW_VERSION_FIELD_NUMBER: _ClassVar[int]
    SW_VERSION_HOST_FIELD_NUMBER: _ClassVar[int]
    SERIAL_NUM_FIELD_NUMBER: _ClassVar[int]
    SW_VERSION_PLD_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    canmsg: str
    interface_version: int
    hw_version: int
    sw_version_host: str
    serial_num: str
    sw_version_pld: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., canmsg: _Optional[str] = ..., interface_version: _Optional[int] = ..., hw_version: _Optional[int] = ..., sw_version_host: _Optional[str] = ..., serial_num: _Optional[str] = ..., sw_version_pld: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as _pose_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SpawnEntityRequest(_message.Message):
    __slots__ = ("header", "name", "xml", "robot_namespace", "initial_pose", "reference_frame")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    XML_FIELD_NUMBER: _ClassVar[int]
    ROBOT_NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    INITIAL_POSE_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_FRAME_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    name: str
    xml: str
    robot_namespace: str
    initial_pose: _pose_pb2.Pose
    reference_frame: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., name: _Optional[str] = ..., xml: _Optional[str] = ..., robot_namespace: _Optional[str] = ..., initial_pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., reference_frame: _Optional[str] = ...) -> None: ...

class SpawnEntityResponse(_message.Message):
    __slots__ = ("header", "success", "status_message")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    STATUS_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    status_message: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ..., status_message: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.rolling.geometry_msgs.msg import point_pb2 as _point_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Vertex(_message.Message):
    __slots__ = ("id", "valid", "path", "weight", "width", "successors", "predecessors")
    ID_FIELD_NUMBER: _ClassVar[int]
    VALID_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    WEIGHT_FIELD_NUMBER: _ClassVar[int]
    WIDTH_FIELD_NUMBER: _ClassVar[int]
    SUCCESSORS_FIELD_NUMBER: _ClassVar[int]
    PREDECESSORS_FIELD_NUMBER: _ClassVar[int]
    id: int
    valid: bool
    path: _containers.RepeatedCompositeFieldContainer[_point_pb2.Point]
    weight: int
    width: float
    successors: _containers.RepeatedScalarFieldContainer[int]
    predecessors: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, id: _Optional[int] = ..., valid: bool = ..., path: _Optional[_Iterable[_Union[_point_pb2.Point, _Mapping]]] = ..., weight: _Optional[int] = ..., width: _Optional[float] = ..., successors: _Optional[_Iterable[int]] = ..., predecessors: _Optional[_Iterable[int]] = ...) -> None: ...



from make87_messages_ros2.rolling.derived_object_msgs.msg import lane_pb2 as _lane_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LaneModels(_message.Message):
    __slots__ = ("header", "left_lane", "right_lane", "additional_lanes")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    LEFT_LANE_FIELD_NUMBER: _ClassVar[int]
    RIGHT_LANE_FIELD_NUMBER: _ClassVar[int]
    ADDITIONAL_LANES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    left_lane: _lane_pb2.Lane
    right_lane: _lane_pb2.Lane
    additional_lanes: _containers.RepeatedCompositeFieldContainer[_lane_pb2.Lane]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., left_lane: _Optional[_Union[_lane_pb2.Lane, _Mapping]] = ..., right_lane: _Optional[_Union[_lane_pb2.Lane, _Mapping]] = ..., additional_lanes: _Optional[_Iterable[_Union[_lane_pb2.Lane, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mavros_msgs/msg/hil_sensor.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_vector3__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/rolling/mavros_msgs/msg/hil_sensor.proto\x12,make87_messages_ros2.rolling.mavros_msgs.msg\x1a<make87_messages_ros2/rolling/geometry_msgs/msg/vector3.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\x91\x03\n\tHilSensor\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x44\n\x03\x61\x63\x63\x18\x02 \x01(\x0b\x32\x37.make87_messages_ros2.rolling.geometry_msgs.msg.Vector3\x12\x45\n\x04gyro\x18\x03 \x01(\x0b\x32\x37.make87_messages_ros2.rolling.geometry_msgs.msg.Vector3\x12\x44\n\x03mag\x18\x04 \x01(\x0b\x32\x37.make87_messages_ros2.rolling.geometry_msgs.msg.Vector3\x12\x14\n\x0c\x61\x62s_pressure\x18\x05 \x01(\x02\x12\x15\n\rdiff_pressure\x18\x06 \x01(\x02\x12\x14\n\x0cpressure_alt\x18\x07 \x01(\x02\x12\x13\n\x0btemperature\x18\x08 \x01(\x02\x12\x16\n\x0e\x66ields_updated\x18\t \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mavros_msgs.msg.hil_sensor_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_HILSENSOR']._serialized_start=230
  _globals['_HILSENSOR']._serialized_end=631
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DiagnosticsEthernetConfigurationInformation(_message.Message):
    __slots__ = ("header", "ip_address", "netmask", "vlan", "port")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    IP_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    NETMASK_FIELD_NUMBER: _ClassVar[int]
    VLAN_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ip_address: str
    netmask: str
    vlan: int
    port: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ip_address: _Optional[str] = ..., netmask: _Optional[str] = ..., vlan: _Optional[int] = ..., port: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.rolling.tuw_object_msgs.msg import shape_array_pb2 as _shape_array_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetShapeArrayRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetShapeArrayResponse(_message.Message):
    __slots__ = ("shapes",)
    SHAPES_FIELD_NUMBER: _ClassVar[int]
    shapes: _shape_array_pb2.ShapeArray
    def __init__(self, shapes: _Optional[_Union[_shape_array_pb2.ShapeArray, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mavros_msgs/msg/gimbal_manager_set_attitude.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import quaternion_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_quaternion__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNmake87_messages_ros2/rolling/mavros_msgs/msg/gimbal_manager_set_attitude.proto\x12,make87_messages_ros2.rolling.mavros_msgs.msg\x1a?make87_messages_ros2/rolling/geometry_msgs/msg/quaternion.proto\"\x8f\x02\n\x18GimbalManagerSetAttitude\x12\x15\n\rtarget_system\x18\x01 \x01(\r\x12\x18\n\x10target_component\x18\x02 \x01(\r\x12\r\n\x05\x66lags\x18\x03 \x01(\r\x12\x18\n\x10gimbal_device_id\x18\x04 \x01(\r\x12\x45\n\x01q\x18\x05 \x01(\x0b\x32:.make87_messages_ros2.rolling.geometry_msgs.msg.Quaternion\x12\x1a\n\x12\x61ngular_velocity_x\x18\x06 \x01(\x02\x12\x1a\n\x12\x61ngular_velocity_y\x18\x07 \x01(\x02\x12\x1a\n\x12\x61ngular_velocity_z\x18\x08 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mavros_msgs.msg.gimbal_manager_set_attitude_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GIMBALMANAGERSETATTITUDE']._serialized_start=194
  _globals['_GIMBALMANAGERSETATTITUDE']._serialized_end=465
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/py_trees_ros_interfaces/msg/behaviour_tree.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.diagnostic_msgs.msg import key_value_pb2 as make87__messages__ros2_dot_rolling_dot_diagnostic__msgs_dot_msg_dot_key__value__pb2
from make87_messages_ros2.rolling.py_trees_ros_interfaces.msg import activity_item_pb2 as make87__messages__ros2_dot_rolling_dot_py__trees__ros__interfaces_dot_msg_dot_activity__item__pb2
from make87_messages_ros2.rolling.py_trees_ros_interfaces.msg import behaviour_pb2 as make87__messages__ros2_dot_rolling_dot_py__trees__ros__interfaces_dot_msg_dot_behaviour__pb2
from make87_messages_ros2.rolling.py_trees_ros_interfaces.msg import statistics_pb2 as make87__messages__ros2_dot_rolling_dot_py__trees__ros__interfaces_dot_msg_dot_statistics__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMmake87_messages_ros2/rolling/py_trees_ros_interfaces/msg/behaviour_tree.proto\x12\x38make87_messages_ros2.rolling.py_trees_ros_interfaces.msg\x1a@make87_messages_ros2/rolling/diagnostic_msgs/msg/key_value.proto\x1aLmake87_messages_ros2/rolling/py_trees_ros_interfaces/msg/activity_item.proto\x1aHmake87_messages_ros2/rolling/py_trees_ros_interfaces/msg/behaviour.proto\x1aImake87_messages_ros2/rolling/py_trees_ros_interfaces/msg/statistics.proto\"\x98\x03\n\rBehaviourTree\x12W\n\nbehaviours\x18\x01 \x03(\x0b\x32\x43.make87_messages_ros2.rolling.py_trees_ros_interfaces.msg.Behaviour\x12\x0f\n\x07\x63hanged\x18\x02 \x01(\x08\x12^\n\x1a\x62lackboard_on_visited_path\x18\x03 \x03(\x0b\x32:.make87_messages_ros2.rolling.diagnostic_msgs.msg.KeyValue\x12\x63\n\x13\x62lackboard_activity\x18\x04 \x03(\x0b\x32\x46.make87_messages_ros2.rolling.py_trees_ros_interfaces.msg.ActivityItem\x12X\n\nstatistics\x18\x05 \x01(\x0b\x32\x44.make87_messages_ros2.rolling.py_trees_ros_interfaces.msg.Statisticsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.py_trees_ros_interfaces.msg.behaviour_tree_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_BEHAVIOURTREE']._serialized_start=433
  _globals['_BEHAVIOURTREE']._serialized_end=841
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/novatel_gps_msgs/msg/novatel_signal_mask.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/rolling/novatel_gps_msgs/msg/novatel_signal_mask.proto\x12\x31make87_messages_ros2.rolling.novatel_gps_msgs.msg\"\xd7\x01\n\x11NovatelSignalMask\x12\x15\n\roriginal_mask\x18\x01 \x01(\r\x12\x1f\n\x17gps_l1_used_in_solution\x18\x02 \x01(\x08\x12\x1f\n\x17gps_l2_used_in_solution\x18\x03 \x01(\x08\x12\x1f\n\x17gps_l3_used_in_solution\x18\x04 \x01(\x08\x12#\n\x1bglonass_l1_used_in_solution\x18\x05 \x01(\x08\x12#\n\x1bglonass_l2_used_in_solution\x18\x06 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.novatel_gps_msgs.msg.novatel_signal_mask_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_NOVATELSIGNALMASK']._serialized_start=131
  _globals['_NOVATELSIGNALMASK']._serialized_end=346
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/qb_device_msgs/srv/set_commands.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/humble/qb_device_msgs/srv/set_commands.proto\x12.make87_messages_ros2.humble.qb_device_msgs.srv\x1a!make87_messages/core/header.proto\"\xa7\x01\n\x12SetCommandsRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\n\n\x02id\x18\x02 \x01(\x05\x12\x13\n\x0bmax_repeats\x18\x03 \x01(\x05\x12\x14\n\x0cset_commands\x18\x04 \x01(\x08\x12\x1a\n\x12set_commands_async\x18\x05 \x01(\x08\x12\x10\n\x08\x63ommands\x18\x06 \x03(\x05\"f\n\x13SetCommandsResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x10\n\x08\x66\x61ilures\x18\x03 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.qb_device_msgs.srv.set_commands_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SETCOMMANDSREQUEST']._serialized_start=153
  _globals['_SETCOMMANDSREQUEST']._serialized_end=320
  _globals['_SETCOMMANDSRESPONSE']._serialized_start=322
  _globals['_SETCOMMANDSRESPONSE']._serialized_end=424
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.mavros_msgs.msg import vehicle_info_pb2 as _vehicle_info_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VehicleInfoGetRequest(_message.Message):
    __slots__ = ("sysid", "compid", "get_all")
    SYSID_FIELD_NUMBER: _ClassVar[int]
    COMPID_FIELD_NUMBER: _ClassVar[int]
    GET_ALL_FIELD_NUMBER: _ClassVar[int]
    sysid: int
    compid: int
    get_all: bool
    def __init__(self, sysid: _Optional[int] = ..., compid: _Optional[int] = ..., get_all: bool = ...) -> None: ...

class VehicleInfoGetResponse(_message.Message):
    __slots__ = ("success", "vehicles")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    VEHICLES_FIELD_NUMBER: _ClassVar[int]
    success: bool
    vehicles: _containers.RepeatedCompositeFieldContainer[_vehicle_info_pb2.VehicleInfo]
    def __init__(self, success: bool = ..., vehicles: _Optional[_Iterable[_Union[_vehicle_info_pb2.VehicleInfo, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from make87_messages_ros2.rolling.ublox_ubx_msgs.msg import sig_log_event_pb2 as _sig_log_event_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UBXSecSigLog(_message.Message):
    __slots__ = ("header", "version", "num_events", "events")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    NUM_EVENTS_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    version: int
    num_events: int
    events: _containers.RepeatedCompositeFieldContainer[_sig_log_event_pb2.SigLogEvent]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., version: _Optional[int] = ..., num_events: _Optional[int] = ..., events: _Optional[_Iterable[_Union[_sig_log_event_pb2.SigLogEvent, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SbgOdoVel(_message.Message):
    __slots__ = ("header", "time_stamp", "status", "vel")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TIME_STAMP_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    VEL_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    time_stamp: int
    status: bool
    vel: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., time_stamp: _Optional[int] = ..., status: bool = ..., vel: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.jazzy.septentrio_gnss_driver.msg import block_header_pb2 as _block_header_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AttEuler(_message.Message):
    __slots__ = ("header", "block_header", "nr_sv", "error", "mode", "heading", "pitch", "roll", "pitch_dot", "roll_dot", "heading_dot")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BLOCK_HEADER_FIELD_NUMBER: _ClassVar[int]
    NR_SV_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    HEADING_FIELD_NUMBER: _ClassVar[int]
    PITCH_FIELD_NUMBER: _ClassVar[int]
    ROLL_FIELD_NUMBER: _ClassVar[int]
    PITCH_DOT_FIELD_NUMBER: _ClassVar[int]
    ROLL_DOT_FIELD_NUMBER: _ClassVar[int]
    HEADING_DOT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    block_header: _block_header_pb2.BlockHeader
    nr_sv: int
    error: int
    mode: int
    heading: float
    pitch: float
    roll: float
    pitch_dot: float
    roll_dot: float
    heading_dot: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., block_header: _Optional[_Union[_block_header_pb2.BlockHeader, _Mapping]] = ..., nr_sv: _Optional[int] = ..., error: _Optional[int] = ..., mode: _Optional[int] = ..., heading: _Optional[float] = ..., pitch: _Optional[float] = ..., roll: _Optional[float] = ..., pitch_dot: _Optional[float] = ..., roll_dot: _Optional[float] = ..., heading_dot: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import transform_pb2 as _transform_pb2
from make87_messages_ros2.jazzy.rtabmap_msgs.msg import camera_models_pb2 as _camera_models_pb2
from make87_messages_ros2.jazzy.rtabmap_msgs.msg import key_point_pb2 as _key_point_pb2
from make87_messages_ros2.jazzy.rtabmap_msgs.msg import point2f_pb2 as _point2f_pb2
from make87_messages_ros2.jazzy.rtabmap_msgs.msg import point3f_pb2 as _point3f_pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import point_cloud2_pb2 as _point_cloud2_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class OdomInfo(_message.Message):
    __slots__ = ("header", "lost", "matches", "inliers", "icp_inliers_ratio", "icp_rotation", "icp_translation", "icp_structural_complexity", "icp_structural_distribution", "icp_correspondences", "covariance", "features", "local_map_size", "local_scan_map_size", "local_key_frames", "local_bundle_outliers", "local_bundle_constraints", "local_bundle_time", "key_frame_added", "time_estimation", "time_particle_filtering", "stamp", "interval", "distance_travelled", "memory_usage", "gravity_roll_error", "gravity_pitch_error", "local_bundle_ids", "local_bundle_models", "local_bundle_poses", "transform", "transform_filtered", "transform_ground_truth", "guess", "type", "words_keys", "words_values", "word_matches", "word_inliers", "local_map_keys", "local_map_values", "local_scan_map", "ref_corners", "new_corners", "corner_inliers")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    LOST_FIELD_NUMBER: _ClassVar[int]
    MATCHES_FIELD_NUMBER: _ClassVar[int]
    INLIERS_FIELD_NUMBER: _ClassVar[int]
    ICP_INLIERS_RATIO_FIELD_NUMBER: _ClassVar[int]
    ICP_ROTATION_FIELD_NUMBER: _ClassVar[int]
    ICP_TRANSLATION_FIELD_NUMBER: _ClassVar[int]
    ICP_STRUCTURAL_COMPLEXITY_FIELD_NUMBER: _ClassVar[int]
    ICP_STRUCTURAL_DISTRIBUTION_FIELD_NUMBER: _ClassVar[int]
    ICP_CORRESPONDENCES_FIELD_NUMBER: _ClassVar[int]
    COVARIANCE_FIELD_NUMBER: _ClassVar[int]
    FEATURES_FIELD_NUMBER: _ClassVar[int]
    LOCAL_MAP_SIZE_FIELD_NUMBER: _ClassVar[int]
    LOCAL_SCAN_MAP_SIZE_FIELD_NUMBER: _ClassVar[int]
    LOCAL_KEY_FRAMES_FIELD_NUMBER: _ClassVar[int]
    LOCAL_BUNDLE_OUTLIERS_FIELD_NUMBER: _ClassVar[int]
    LOCAL_BUNDLE_CONSTRAINTS_FIELD_NUMBER: _ClassVar[int]
    LOCAL_BUNDLE_TIME_FIELD_NUMBER: _ClassVar[int]
    KEY_FRAME_ADDED_FIELD_NUMBER: _ClassVar[int]
    TIME_ESTIMATION_FIELD_NUMBER: _ClassVar[int]
    TIME_PARTICLE_FILTERING_FIELD_NUMBER: _ClassVar[int]
    STAMP_FIELD_NUMBER: _ClassVar[int]
    INTERVAL_FIELD_NUMBER: _ClassVar[int]
    DISTANCE_TRAVELLED_FIELD_NUMBER: _ClassVar[int]
    MEMORY_USAGE_FIELD_NUMBER: _ClassVar[int]
    GRAVITY_ROLL_ERROR_FIELD_NUMBER: _ClassVar[int]
    GRAVITY_PITCH_ERROR_FIELD_NUMBER: _ClassVar[int]
    LOCAL_BUNDLE_IDS_FIELD_NUMBER: _ClassVar[int]
    LOCAL_BUNDLE_MODELS_FIELD_NUMBER: _ClassVar[int]
    LOCAL_BUNDLE_POSES_FIELD_NUMBER: _ClassVar[int]
    TRANSFORM_FIELD_NUMBER: _ClassVar[int]
    TRANSFORM_FILTERED_FIELD_NUMBER: _ClassVar[int]
    TRANSFORM_GROUND_TRUTH_FIELD_NUMBER: _ClassVar[int]
    GUESS_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    WORDS_KEYS_FIELD_NUMBER: _ClassVar[int]
    WORDS_VALUES_FIELD_NUMBER: _ClassVar[int]
    WORD_MATCHES_FIELD_NUMBER: _ClassVar[int]
    WORD_INLIERS_FIELD_NUMBER: _ClassVar[int]
    LOCAL_MAP_KEYS_FIELD_NUMBER: _ClassVar[int]
    LOCAL_MAP_VALUES_FIELD_NUMBER: _ClassVar[int]
    LOCAL_SCAN_MAP_FIELD_NUMBER: _ClassVar[int]
    REF_CORNERS_FIELD_NUMBER: _ClassVar[int]
    NEW_CORNERS_FIELD_NUMBER: _ClassVar[int]
    CORNER_INLIERS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    lost: bool
    matches: int
    inliers: int
    icp_inliers_ratio: float
    icp_rotation: float
    icp_translation: float
    icp_structural_complexity: float
    icp_structural_distribution: float
    icp_correspondences: int
    covariance: _containers.RepeatedScalarFieldContainer[float]
    features: int
    local_map_size: int
    local_scan_map_size: int
    local_key_frames: int
    local_bundle_outliers: int
    local_bundle_constraints: int
    local_bundle_time: float
    key_frame_added: bool
    time_estimation: float
    time_particle_filtering: float
    stamp: float
    interval: float
    distance_travelled: float
    memory_usage: int
    gravity_roll_error: float
    gravity_pitch_error: float
    local_bundle_ids: _containers.RepeatedScalarFieldContainer[int]
    local_bundle_models: _containers.RepeatedCompositeFieldContainer[_camera_models_pb2.CameraModels]
    local_bundle_poses: _containers.RepeatedCompositeFieldContainer[_pose_pb2.Pose]
    transform: _transform_pb2.Transform
    transform_filtered: _transform_pb2.Transform
    transform_ground_truth: _transform_pb2.Transform
    guess: _transform_pb2.Transform
    type: int
    words_keys: _containers.RepeatedScalarFieldContainer[int]
    words_values: _containers.RepeatedCompositeFieldContainer[_key_point_pb2.KeyPoint]
    word_matches: _containers.RepeatedScalarFieldContainer[int]
    word_inliers: _containers.RepeatedScalarFieldContainer[int]
    local_map_keys: _containers.RepeatedScalarFieldContainer[int]
    local_map_values: _containers.RepeatedCompositeFieldContainer[_point3f_pb2.Point3f]
    local_scan_map: _point_cloud2_pb2.PointCloud2
    ref_corners: _containers.RepeatedCompositeFieldContainer[_point2f_pb2.Point2f]
    new_corners: _containers.RepeatedCompositeFieldContainer[_point2f_pb2.Point2f]
    corner_inliers: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., lost: bool = ..., matches: _Optional[int] = ..., inliers: _Optional[int] = ..., icp_inliers_ratio: _Optional[float] = ..., icp_rotation: _Optional[float] = ..., icp_translation: _Optional[float] = ..., icp_structural_complexity: _Optional[float] = ..., icp_structural_distribution: _Optional[float] = ..., icp_correspondences: _Optional[int] = ..., covariance: _Optional[_Iterable[float]] = ..., features: _Optional[int] = ..., local_map_size: _Optional[int] = ..., local_scan_map_size: _Optional[int] = ..., local_key_frames: _Optional[int] = ..., local_bundle_outliers: _Optional[int] = ..., local_bundle_constraints: _Optional[int] = ..., local_bundle_time: _Optional[float] = ..., key_frame_added: bool = ..., time_estimation: _Optional[float] = ..., time_particle_filtering: _Optional[float] = ..., stamp: _Optional[float] = ..., interval: _Optional[float] = ..., distance_travelled: _Optional[float] = ..., memory_usage: _Optional[int] = ..., gravity_roll_error: _Optional[float] = ..., gravity_pitch_error: _Optional[float] = ..., local_bundle_ids: _Optional[_Iterable[int]] = ..., local_bundle_models: _Optional[_Iterable[_Union[_camera_models_pb2.CameraModels, _Mapping]]] = ..., local_bundle_poses: _Optional[_Iterable[_Union[_pose_pb2.Pose, _Mapping]]] = ..., transform: _Optional[_Union[_transform_pb2.Transform, _Mapping]] = ..., transform_filtered: _Optional[_Union[_transform_pb2.Transform, _Mapping]] = ..., transform_ground_truth: _Optional[_Union[_transform_pb2.Transform, _Mapping]] = ..., guess: _Optional[_Union[_transform_pb2.Transform, _Mapping]] = ..., type: _Optional[int] = ..., words_keys: _Optional[_Iterable[int]] = ..., words_values: _Optional[_Iterable[_Union[_key_point_pb2.KeyPoint, _Mapping]]] = ..., word_matches: _Optional[_Iterable[int]] = ..., word_inliers: _Optional[_Iterable[int]] = ..., local_map_keys: _Optional[_Iterable[int]] = ..., local_map_values: _Optional[_Iterable[_Union[_point3f_pb2.Point3f, _Mapping]]] = ..., local_scan_map: _Optional[_Union[_point_cloud2_pb2.PointCloud2, _Mapping]] = ..., ref_corners: _Optional[_Iterable[_Union[_point2f_pb2.Point2f, _Mapping]]] = ..., new_corners: _Optional[_Iterable[_Union[_point2f_pb2.Point2f, _Mapping]]] = ..., corner_inliers: _Optional[_Iterable[int]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Status(_message.Message):
    __slots__ = ("header", "operating_mode", "area_number", "error_status", "error_code", "lockout_status", "ossd_1", "ossd_2", "warning_1", "warning_2", "ossd_3", "ossd_4", "distance", "angle")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    OPERATING_MODE_FIELD_NUMBER: _ClassVar[int]
    AREA_NUMBER_FIELD_NUMBER: _ClassVar[int]
    ERROR_STATUS_FIELD_NUMBER: _ClassVar[int]
    ERROR_CODE_FIELD_NUMBER: _ClassVar[int]
    LOCKOUT_STATUS_FIELD_NUMBER: _ClassVar[int]
    OSSD_1_FIELD_NUMBER: _ClassVar[int]
    OSSD_2_FIELD_NUMBER: _ClassVar[int]
    WARNING_1_FIELD_NUMBER: _ClassVar[int]
    WARNING_2_FIELD_NUMBER: _ClassVar[int]
    OSSD_3_FIELD_NUMBER: _ClassVar[int]
    OSSD_4_FIELD_NUMBER: _ClassVar[int]
    DISTANCE_FIELD_NUMBER: _ClassVar[int]
    ANGLE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    operating_mode: int
    area_number: int
    error_status: bool
    error_code: int
    lockout_status: bool
    ossd_1: bool
    ossd_2: bool
    warning_1: bool
    warning_2: bool
    ossd_3: bool
    ossd_4: bool
    distance: int
    angle: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., operating_mode: _Optional[int] = ..., area_number: _Optional[int] = ..., error_status: bool = ..., error_code: _Optional[int] = ..., lockout_status: bool = ..., ossd_1: bool = ..., ossd_2: bool = ..., warning_1: bool = ..., warning_2: bool = ..., ossd_3: bool = ..., ossd_4: bool = ..., distance: _Optional[int] = ..., angle: _Optional[float] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.ros_gz_interfaces.msg import entity_pb2 as _entity_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DeleteEntityRequest(_message.Message):
    __slots__ = ("header", "entity")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ENTITY_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    entity: _entity_pb2.Entity
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., entity: _Optional[_Union[_entity_pb2.Entity, _Mapping]] = ...) -> None: ...

class DeleteEntityResponse(_message.Message):
    __slots__ = ("header", "success")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.jazzy.soccer_vision_attribute_msgs.msg import confidence_pb2 as _confidence_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MarkingEllipse(_message.Message):
    __slots__ = ("diameter", "center", "confidence")
    DIAMETER_FIELD_NUMBER: _ClassVar[int]
    CENTER_FIELD_NUMBER: _ClassVar[int]
    CONFIDENCE_FIELD_NUMBER: _ClassVar[int]
    diameter: float
    center: _pose_pb2.Pose
    confidence: _confidence_pb2.Confidence
    def __init__(self, diameter: _Optional[float] = ..., center: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., confidence: _Optional[_Union[_confidence_pb2.Confidence, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/turtlesim/srv/teleport_relative.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/jazzy/turtlesim/srv/teleport_relative.proto\x12(make87_messages_ros2.jazzy.turtlesim.srv\":\n\x17TeleportRelativeRequest\x12\x0e\n\x06linear\x18\x01 \x01(\x02\x12\x0f\n\x07\x61ngular\x18\x02 \x01(\x02\"\x1a\n\x18TeleportRelativeResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.turtlesim.srv.teleport_relative_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TELEPORTRELATIVEREQUEST']._serialized_start=110
  _globals['_TELEPORTRELATIVEREQUEST']._serialized_end=168
  _globals['_TELEPORTRELATIVERESPONSE']._serialized_start=170
  _globals['_TELEPORTRELATIVERESPONSE']._serialized_end=196
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class OpenBlackboardStreamRequest(_message.Message):
    __slots__ = ("header", "variables", "filter_on_visited_path", "with_activity_stream")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    VARIABLES_FIELD_NUMBER: _ClassVar[int]
    FILTER_ON_VISITED_PATH_FIELD_NUMBER: _ClassVar[int]
    WITH_ACTIVITY_STREAM_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    variables: _containers.RepeatedScalarFieldContainer[str]
    filter_on_visited_path: bool
    with_activity_stream: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., variables: _Optional[_Iterable[str]] = ..., filter_on_visited_path: bool = ..., with_activity_stream: bool = ...) -> None: ...

class OpenBlackboardStreamResponse(_message.Message):
    __slots__ = ("header", "topic")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TOPIC_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    topic: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., topic: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/sbg_driver/msg/sbg_status_aiding.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/sbg_driver/msg/sbg_status_aiding.proto\x12)make87_messages_ros2.jazzy.sbg_driver.msg\"\x86\x03\n\x0fSbgStatusAiding\x12\x15\n\rgps1_pos_recv\x18\x01 \x01(\x08\x12\x15\n\rgps1_vel_recv\x18\x02 \x01(\x08\x12\x15\n\rgps1_hdt_recv\x18\x03 \x01(\x08\x12\x15\n\rgps1_utc_recv\x18\x04 \x01(\x08\x12\x15\n\rgps2_pos_recv\x18\x05 \x01(\x08\x12\x15\n\rgps2_vel_recv\x18\x06 \x01(\x08\x12\x15\n\rgps2_hdt_recv\x18\x07 \x01(\x08\x12\x15\n\rgps2_utc_recv\x18\x08 \x01(\x08\x12\x10\n\x08mag_recv\x18\t \x01(\x08\x12\x10\n\x08odo_recv\x18\n \x01(\x08\x12\x10\n\x08\x64vl_recv\x18\x0b \x01(\x08\x12\x11\n\tusbl_recv\x18\x0c \x01(\x08\x12\x12\n\ndepth_recv\x18\r \x01(\x08\x12\x15\n\rair_data_recv\x18\x0e \x01(\x08\x12\x15\n\ruser_pos_recv\x18\x0f \x01(\x08\x12\x15\n\ruser_vel_recv\x18\x10 \x01(\x08\x12\x19\n\x11user_heading_recv\x18\x11 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.sbg_driver.msg.sbg_status_aiding_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SBGSTATUSAIDING']._serialized_start=113
  _globals['_SBGSTATUSAIDING']._serialized_end=503
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/topic_tools_interfaces/srv/demux_list.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/jazzy/topic_tools_interfaces/srv/demux_list.proto\x12\x35make87_messages_ros2.jazzy.topic_tools_interfaces.srv\"\x12\n\x10\x44\x65muxListRequest\"#\n\x11\x44\x65muxListResponse\x12\x0e\n\x06topics\x18\x01 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.topic_tools_interfaces.srv.demux_list_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DEMUXLISTREQUEST']._serialized_start=129
  _globals['_DEMUXLISTREQUEST']._serialized_end=147
  _globals['_DEMUXLISTRESPONSE']._serialized_start=149
  _globals['_DEMUXLISTRESPONSE']._serialized_end=184
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/geographic_msgs/msg/geo_point_stamped.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geographic_msgs.msg import geo_point_pb2 as make87__messages__ros2_dot_rolling_dot_geographic__msgs_dot_msg_dot_geo__point__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/rolling/geographic_msgs/msg/geo_point_stamped.proto\x12\x30make87_messages_ros2.rolling.geographic_msgs.msg\x1a@make87_messages_ros2/rolling/geographic_msgs/msg/geo_point.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xa2\x01\n\x0fGeoPointStamped\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12L\n\x08position\x18\x02 \x01(\x0b\x32:.make87_messages_ros2.rolling.geographic_msgs.msg.GeoPointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.geographic_msgs.msg.geo_point_stamped_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GEOPOINTSTAMPED']._serialized_start=249
  _globals['_GEOPOINTSTAMPED']._serialized_end=411
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/sick_safevisionary_interfaces/msg/io_input_values.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nTmake87_messages_ros2/rolling/sick_safevisionary_interfaces/msg/io_input_values.proto\x12>make87_messages_ros2.rolling.sick_safevisionary_interfaces.msg\"K\n\rIOInputValues\x12\r\n\x05pin_5\x18\x01 \x01(\r\x12\r\n\x05pin_6\x18\x02 \x01(\r\x12\r\n\x05pin_7\x18\x03 \x01(\r\x12\r\n\x05pin_8\x18\x04 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.sick_safevisionary_interfaces.msg.io_input_values_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_IOINPUTVALUES']._serialized_start=152
  _globals['_IOINPUTVALUES']._serialized_end=227
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.rmf_traffic_msgs.msg import blockade_status_pb2 as _blockade_status_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BlockadeHeartbeat(_message.Message):
    __slots__ = ("statuses", "has_gridlock")
    STATUSES_FIELD_NUMBER: _ClassVar[int]
    HAS_GRIDLOCK_FIELD_NUMBER: _ClassVar[int]
    statuses: _containers.RepeatedCompositeFieldContainer[_blockade_status_pb2.BlockadeStatus]
    has_gridlock: bool
    def __init__(self, statuses: _Optional[_Iterable[_Union[_blockade_status_pb2.BlockadeStatus, _Mapping]]] = ..., has_gridlock: bool = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.webots_ros2_msgs.msg import urdf_robot_pb2 as _urdf_robot_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SpawnUrdfRobotRequest(_message.Message):
    __slots__ = ("header", "robot")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROBOT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    robot: _urdf_robot_pb2.UrdfRobot
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., robot: _Optional[_Union[_urdf_robot_pb2.UrdfRobot, _Mapping]] = ...) -> None: ...

class SpawnUrdfRobotResponse(_message.Message):
    __slots__ = ("header", "success")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from make87_messages_ros2.rolling.ublox_ubx_msgs.msg import sat_info_pb2 as _sat_info_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UBXNavSat(_message.Message):
    __slots__ = ("header", "itow", "version", "num_svs", "sv_info")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ITOW_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    NUM_SVS_FIELD_NUMBER: _ClassVar[int]
    SV_INFO_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    itow: int
    version: int
    num_svs: int
    sv_info: _containers.RepeatedCompositeFieldContainer[_sat_info_pb2.SatInfo]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., itow: _Optional[int] = ..., version: _Optional[int] = ..., num_svs: _Optional[int] = ..., sv_info: _Optional[_Iterable[_Union[_sat_info_pb2.SatInfo, _Mapping]]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ParamPullRequest(_message.Message):
    __slots__ = ("force_pull",)
    FORCE_PULL_FIELD_NUMBER: _ClassVar[int]
    force_pull: bool
    def __init__(self, force_pull: bool = ...) -> None: ...

class ParamPullResponse(_message.Message):
    __slots__ = ("success", "param_received")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    PARAM_RECEIVED_FIELD_NUMBER: _ClassVar[int]
    success: bool
    param_received: int
    def __init__(self, success: bool = ..., param_received: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/action_msgs/msg/goal_status_array.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.action_msgs.msg import goal_status_pb2 as make87__messages__ros2_dot_jazzy_dot_action__msgs_dot_msg_dot_goal__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/jazzy/action_msgs/msg/goal_status_array.proto\x12*make87_messages_ros2.jazzy.action_msgs.msg\x1a<make87_messages_ros2/jazzy/action_msgs/msg/goal_status.proto\"^\n\x0fGoalStatusArray\x12K\n\x0bstatus_list\x18\x01 \x03(\x0b\x32\x36.make87_messages_ros2.jazzy.action_msgs.msg.GoalStatusb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.action_msgs.msg.goal_status_array_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GOALSTATUSARRAY']._serialized_start=176
  _globals['_GOALSTATUSARRAY']._serialized_end=270
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Vibration(_message.Message):
    __slots__ = ("header", "vibration", "clipping")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    VIBRATION_FIELD_NUMBER: _ClassVar[int]
    CLIPPING_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    vibration: _vector3_pb2.Vector3
    clipping: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., vibration: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., clipping: _Optional[_Iterable[float]] = ...) -> None: ...



from make87_messages_ros2.jazzy.test_interface_files.msg import basic_types_pb2 as _basic_types_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Nested(_message.Message):
    __slots__ = ("basic_types_value",)
    BASIC_TYPES_VALUE_FIELD_NUMBER: _ClassVar[int]
    basic_types_value: _basic_types_pb2.BasicTypes
    def __init__(self, basic_types_value: _Optional[_Union[_basic_types_pb2.BasicTypes, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/autoware_v2x_msgs/msg/virtual_gate_status.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.autoware_v2x_msgs.msg import virtual_gate_area_status_pb2 as make87__messages__ros2_dot_jazzy_dot_autoware__v2x__msgs_dot_msg_dot_virtual__gate__area__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/jazzy/autoware_v2x_msgs/msg/virtual_gate_status.proto\x12\x30make87_messages_ros2.jazzy.autoware_v2x_msgs.msg\x1aOmake87_messages_ros2/jazzy/autoware_v2x_msgs/msg/virtual_gate_area_status.proto\"k\n\x11VirtualGateStatus\x12V\n\x05\x61reas\x18\x01 \x03(\x0b\x32G.make87_messages_ros2.jazzy.autoware_v2x_msgs.msg.VirtualGateAreaStatusb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.autoware_v2x_msgs.msg.virtual_gate_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_VIRTUALGATESTATUS']._serialized_start=209
  _globals['_VIRTUALGATESTATUS']._serialized_end=316
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ContourPointSigma(_message.Message):
    __slots__ = ("x", "y", "x_sigma", "y_sigma")
    X_FIELD_NUMBER: _ClassVar[int]
    Y_FIELD_NUMBER: _ClassVar[int]
    X_SIGMA_FIELD_NUMBER: _ClassVar[int]
    Y_SIGMA_FIELD_NUMBER: _ClassVar[int]
    x: int
    y: int
    x_sigma: int
    y_sigma: int
    def __init__(self, x: _Optional[int] = ..., y: _Optional[int] = ..., x_sigma: _Optional[int] = ..., y_sigma: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/diagnostic_msgs/srv/add_diagnostics.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/rolling/diagnostic_msgs/srv/add_diagnostics.proto\x12\x30make87_messages_ros2.rolling.diagnostic_msgs.srv\"/\n\x15\x41\x64\x64\x44iagnosticsRequest\x12\x16\n\x0eload_namespace\x18\x01 \x01(\t\":\n\x16\x41\x64\x64\x44iagnosticsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.diagnostic_msgs.srv.add_diagnostics_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ADDDIAGNOSTICSREQUEST']._serialized_start=124
  _globals['_ADDDIAGNOSTICSREQUEST']._serialized_end=171
  _globals['_ADDDIAGNOSTICSRESPONSE']._serialized_start=173
  _globals['_ADDDIAGNOSTICSRESPONSE']._serialized_end=231
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_task_msgs/srv/get_dispatch_states.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rmf_task_msgs.msg import dispatch_states_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__task__msgs_dot_msg_dot_dispatch__states__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/jazzy/rmf_task_msgs/srv/get_dispatch_states.proto\x12,make87_messages_ros2.jazzy.rmf_task_msgs.srv\x1a\x42make87_messages_ros2/jazzy/rmf_task_msgs/msg/dispatch_states.proto\",\n\x18GetDispatchStatesRequest\x12\x10\n\x08task_ids\x18\x01 \x03(\t\"z\n\x19GetDispatchStatesResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12L\n\x06states\x18\x02 \x01(\x0b\x32<.make87_messages_ros2.jazzy.rmf_task_msgs.msg.DispatchStatesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_task_msgs.srv.get_dispatch_states_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETDISPATCHSTATESREQUEST']._serialized_start=188
  _globals['_GETDISPATCHSTATESREQUEST']._serialized_end=232
  _globals['_GETDISPATCHSTATESRESPONSE']._serialized_start=234
  _globals['_GETDISPATCHSTATESRESPONSE']._serialized_end=356
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ParameterValue(_message.Message):
    __slots__ = ("type", "bool_value", "integer_value", "double_value", "string_value", "byte_array_value", "bool_array_value", "integer_array_value", "double_array_value", "string_array_value")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    BOOL_VALUE_FIELD_NUMBER: _ClassVar[int]
    INTEGER_VALUE_FIELD_NUMBER: _ClassVar[int]
    DOUBLE_VALUE_FIELD_NUMBER: _ClassVar[int]
    STRING_VALUE_FIELD_NUMBER: _ClassVar[int]
    BYTE_ARRAY_VALUE_FIELD_NUMBER: _ClassVar[int]
    BOOL_ARRAY_VALUE_FIELD_NUMBER: _ClassVar[int]
    INTEGER_ARRAY_VALUE_FIELD_NUMBER: _ClassVar[int]
    DOUBLE_ARRAY_VALUE_FIELD_NUMBER: _ClassVar[int]
    STRING_ARRAY_VALUE_FIELD_NUMBER: _ClassVar[int]
    type: int
    bool_value: bool
    integer_value: int
    double_value: float
    string_value: str
    byte_array_value: _containers.RepeatedScalarFieldContainer[int]
    bool_array_value: _containers.RepeatedScalarFieldContainer[bool]
    integer_array_value: _containers.RepeatedScalarFieldContainer[int]
    double_array_value: _containers.RepeatedScalarFieldContainer[float]
    string_array_value: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, type: _Optional[int] = ..., bool_value: bool = ..., integer_value: _Optional[int] = ..., double_value: _Optional[float] = ..., string_value: _Optional[str] = ..., byte_array_value: _Optional[_Iterable[int]] = ..., bool_array_value: _Optional[_Iterable[bool]] = ..., integer_array_value: _Optional[_Iterable[int]] = ..., double_array_value: _Optional[_Iterable[float]] = ..., string_array_value: _Optional[_Iterable[str]] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SteeringCmd(_message.Message):
    __slots__ = ("header", "cmd", "cmd_rate", "cmd_accel", "cmd_type", "enable", "clear", "ignore")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CMD_FIELD_NUMBER: _ClassVar[int]
    CMD_RATE_FIELD_NUMBER: _ClassVar[int]
    CMD_ACCEL_FIELD_NUMBER: _ClassVar[int]
    CMD_TYPE_FIELD_NUMBER: _ClassVar[int]
    ENABLE_FIELD_NUMBER: _ClassVar[int]
    CLEAR_FIELD_NUMBER: _ClassVar[int]
    IGNORE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    cmd: float
    cmd_rate: float
    cmd_accel: float
    cmd_type: int
    enable: bool
    clear: bool
    ignore: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., cmd: _Optional[float] = ..., cmd_rate: _Optional[float] = ..., cmd_accel: _Optional[float] = ..., cmd_type: _Optional[int] = ..., enable: bool = ..., clear: bool = ..., ignore: bool = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ScanPoint2204(_message.Message):
    __slots__ = ("x_position", "y_position", "z_position", "echo_width", "device_id", "layer", "echo", "time_offset", "ground", "dirt", "precipitation")
    X_POSITION_FIELD_NUMBER: _ClassVar[int]
    Y_POSITION_FIELD_NUMBER: _ClassVar[int]
    Z_POSITION_FIELD_NUMBER: _ClassVar[int]
    ECHO_WIDTH_FIELD_NUMBER: _ClassVar[int]
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    LAYER_FIELD_NUMBER: _ClassVar[int]
    ECHO_FIELD_NUMBER: _ClassVar[int]
    TIME_OFFSET_FIELD_NUMBER: _ClassVar[int]
    GROUND_FIELD_NUMBER: _ClassVar[int]
    DIRT_FIELD_NUMBER: _ClassVar[int]
    PRECIPITATION_FIELD_NUMBER: _ClassVar[int]
    x_position: float
    y_position: float
    z_position: float
    echo_width: float
    device_id: int
    layer: int
    echo: int
    time_offset: int
    ground: bool
    dirt: bool
    precipitation: bool
    def __init__(self, x_position: _Optional[float] = ..., y_position: _Optional[float] = ..., z_position: _Optional[float] = ..., echo_width: _Optional[float] = ..., device_id: _Optional[int] = ..., layer: _Optional[int] = ..., echo: _Optional[int] = ..., time_offset: _Optional[int] = ..., ground: bool = ..., dirt: bool = ..., precipitation: bool = ...) -> None: ...



from make87_messages_ros2.jazzy.ublox_msgs.msg import rxm_rawx_meas_pb2 as _rxm_rawx_meas_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RxmRAWX(_message.Message):
    __slots__ = ("rcv_tow", "week", "leap_s", "num_meas", "rec_stat", "version", "reserved1", "meas")
    RCV_TOW_FIELD_NUMBER: _ClassVar[int]
    WEEK_FIELD_NUMBER: _ClassVar[int]
    LEAP_S_FIELD_NUMBER: _ClassVar[int]
    NUM_MEAS_FIELD_NUMBER: _ClassVar[int]
    REC_STAT_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    RESERVED1_FIELD_NUMBER: _ClassVar[int]
    MEAS_FIELD_NUMBER: _ClassVar[int]
    rcv_tow: float
    week: int
    leap_s: int
    num_meas: int
    rec_stat: int
    version: int
    reserved1: _containers.RepeatedScalarFieldContainer[int]
    meas: _containers.RepeatedCompositeFieldContainer[_rxm_rawx_meas_pb2.RxmRAWXMeas]
    def __init__(self, rcv_tow: _Optional[float] = ..., week: _Optional[int] = ..., leap_s: _Optional[int] = ..., num_meas: _Optional[int] = ..., rec_stat: _Optional[int] = ..., version: _Optional[int] = ..., reserved1: _Optional[_Iterable[int]] = ..., meas: _Optional[_Iterable[_Union[_rxm_rawx_meas_pb2.RxmRAWXMeas, _Mapping]]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class MessageIntervalRequest(_message.Message):
    __slots__ = ("message_id", "message_rate")
    MESSAGE_ID_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_RATE_FIELD_NUMBER: _ClassVar[int]
    message_id: int
    message_rate: float
    def __init__(self, message_id: _Optional[int] = ..., message_rate: _Optional[float] = ...) -> None: ...

class MessageIntervalResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import point_pb2 as _point_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Object(_message.Message):
    __slots__ = ("header", "ros2_header", "id", "position_first", "exist_probability", "position_second", "object_type")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    POSITION_FIRST_FIELD_NUMBER: _ClassVar[int]
    EXIST_PROBABILITY_FIELD_NUMBER: _ClassVar[int]
    POSITION_SECOND_FIELD_NUMBER: _ClassVar[int]
    OBJECT_TYPE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    id: int
    position_first: _point_pb2.Point
    exist_probability: float
    position_second: _point_pb2.Point
    object_type: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., id: _Optional[int] = ..., position_first: _Optional[_Union[_point_pb2.Point, _Mapping]] = ..., exist_probability: _Optional[float] = ..., position_second: _Optional[_Union[_point_pb2.Point, _Mapping]] = ..., object_type: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ublox_msgs/msg/nav_pvt.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/rolling/ublox_msgs/msg/nav_pvt.proto\x12+make87_messages_ros2.rolling.ublox_msgs.msg\"\xf3\x03\n\x06NavPVT\x12\r\n\x05i_tow\x18\x01 \x01(\r\x12\x0c\n\x04year\x18\x02 \x01(\r\x12\r\n\x05month\x18\x03 \x01(\r\x12\x0b\n\x03\x64\x61y\x18\x04 \x01(\r\x12\x0c\n\x04hour\x18\x05 \x01(\r\x12\x0b\n\x03min\x18\x06 \x01(\r\x12\x0b\n\x03sec\x18\x07 \x01(\r\x12\r\n\x05valid\x18\x08 \x01(\r\x12\r\n\x05t_acc\x18\t \x01(\r\x12\x0c\n\x04nano\x18\n \x01(\x05\x12\x10\n\x08\x66ix_type\x18\x0b \x01(\r\x12\r\n\x05\x66lags\x18\x0c \x01(\r\x12\x0e\n\x06\x66lags2\x18\r \x01(\r\x12\x0e\n\x06num_sv\x18\x0e \x01(\r\x12\x0b\n\x03lon\x18\x0f \x01(\x05\x12\x0b\n\x03lat\x18\x10 \x01(\x05\x12\x0e\n\x06height\x18\x11 \x01(\x05\x12\r\n\x05h_msl\x18\x12 \x01(\x05\x12\r\n\x05h_acc\x18\x13 \x01(\r\x12\r\n\x05v_acc\x18\x14 \x01(\r\x12\r\n\x05vel_n\x18\x15 \x01(\x05\x12\r\n\x05vel_e\x18\x16 \x01(\x05\x12\r\n\x05vel_d\x18\x17 \x01(\x05\x12\x0f\n\x07g_speed\x18\x18 \x01(\x05\x12\x0f\n\x07heading\x18\x19 \x01(\x05\x12\r\n\x05s_acc\x18\x1a \x01(\r\x12\x10\n\x08head_acc\x18\x1b \x01(\r\x12\r\n\x05p_dop\x18\x1c \x01(\r\x12\x11\n\treserved1\x18\x1d \x03(\r\x12\x10\n\x08head_veh\x18\x1e \x01(\x05\x12\x0f\n\x07mag_dec\x18\x1f \x01(\x05\x12\x0f\n\x07mag_acc\x18  \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ublox_msgs.msg.nav_pvt_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_NAVPVT']._serialized_start=107
  _globals['_NAVPVT']._serialized_end=606
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/delphi_mrr_msgs/msg/mrr_status_radar.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/humble/delphi_mrr_msgs/msg/mrr_status_radar.proto\x12/make87_messages_ros2.humble.delphi_mrr_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\x8d\x04\n\x0eMrrStatusRadar\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x1d\n\x15\x63\x61n_interference_type\x18\x03 \x01(\r\x12 \n\x18\x63\x61n_recommend_unconverge\x18\x04 \x01(\x08\x12(\n can_blockage_sidelobe_filter_val\x18\x05 \x01(\r\x12\"\n\x1a\x63\x61n_radar_align_incomplete\x18\x06 \x01(\x08\x12\x1d\n\x15\x63\x61n_blockage_sidelobe\x18\x07 \x01(\x08\x12\x18\n\x10\x63\x61n_blockage_mnr\x18\x08 \x01(\x08\x12\x1e\n\x16\x63\x61n_radar_ext_cond_nok\x18\t \x01(\x08\x12!\n\x19\x63\x61n_radar_align_out_range\x18\n \x01(\x08\x12!\n\x19\x63\x61n_radar_align_not_start\x18\x0b \x01(\x08\x12 \n\x18\x63\x61n_radar_overheat_error\x18\x0c \x01(\x08\x12\x18\n\x10\x63\x61n_radar_not_op\x18\r \x01(\x08\x12\x1c\n\x14\x63\x61n_xcvr_operational\x18\x0e \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.delphi_mrr_msgs.msg.mrr_status_radar_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MRRSTATUSRADAR']._serialized_start=214
  _globals['_MRRSTATUSRADAR']._serialized_end=739
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ActivityItem(_message.Message):
    __slots__ = ("key", "client_name", "activity_type", "previous_value", "current_value")
    KEY_FIELD_NUMBER: _ClassVar[int]
    CLIENT_NAME_FIELD_NUMBER: _ClassVar[int]
    ACTIVITY_TYPE_FIELD_NUMBER: _ClassVar[int]
    PREVIOUS_VALUE_FIELD_NUMBER: _ClassVar[int]
    CURRENT_VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    client_name: str
    activity_type: str
    previous_value: str
    current_value: str
    def __init__(self, key: _Optional[str] = ..., client_name: _Optional[str] = ..., activity_type: _Optional[str] = ..., previous_value: _Optional[str] = ..., current_value: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/autoware_map_msgs/msg/point_cloud_map_cell_with_id.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.autoware_map_msgs.msg import point_cloud_map_cell_meta_data_pb2 as make87__messages__ros2_dot_humble_dot_autoware__map__msgs_dot_msg_dot_point__cloud__map__cell__meta__data__pb2
from make87_messages_ros2.humble.sensor_msgs.msg import point_cloud2_pb2 as make87__messages__ros2_dot_humble_dot_sensor__msgs_dot_msg_dot_point__cloud2__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nTmake87_messages_ros2/humble/autoware_map_msgs/msg/point_cloud_map_cell_with_id.proto\x12\x31make87_messages_ros2.humble.autoware_map_msgs.msg\x1a!make87_messages/core/header.proto\x1aVmake87_messages_ros2/humble/autoware_map_msgs/msg/point_cloud_map_cell_meta_data.proto\x1a>make87_messages_ros2/humble/sensor_msgs/msg/point_cloud2.proto\"\x86\x02\n\x17PointCloudMapCellWithID\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07\x63\x65ll_id\x18\x02 \x01(\t\x12L\n\npointcloud\x18\x03 \x01(\x0b\x32\x38.make87_messages_ros2.humble.sensor_msgs.msg.PointCloud2\x12^\n\x08metadata\x18\x04 \x01(\x0b\x32L.make87_messages_ros2.humble.autoware_map_msgs.msg.PointCloudMapCellMetaDatab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.autoware_map_msgs.msg.point_cloud_map_cell_with_id_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_POINTCLOUDMAPCELLWITHID']._serialized_start=327
  _globals['_POINTCLOUDMAPCELLWITHID']._serialized_end=589
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/kobuki_ros_interfaces/msg/sensor_state.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/jazzy/kobuki_ros_interfaces/msg/sensor_state.proto\x12\x34make87_messages_ros2.jazzy.kobuki_ros_interfaces.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xfe\x02\n\x0bSensorState\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x12\n\ntime_stamp\x18\x02 \x01(\r\x12\x0e\n\x06\x62umper\x18\x03 \x01(\r\x12\x12\n\nwheel_drop\x18\x04 \x01(\r\x12\r\n\x05\x63liff\x18\x05 \x01(\r\x12\x14\n\x0cleft_encoder\x18\x06 \x01(\r\x12\x15\n\rright_encoder\x18\x07 \x01(\r\x12\x10\n\x08left_pwm\x18\x08 \x01(\x05\x12\x11\n\tright_pwm\x18\t \x01(\x05\x12\x0f\n\x07\x62uttons\x18\n \x01(\r\x12\x0f\n\x07\x63harger\x18\x0b \x01(\r\x12\x0f\n\x07\x62\x61ttery\x18\x0c \x01(\r\x12\x0e\n\x06\x62ottom\x18\r \x03(\r\x12\x0f\n\x07\x63urrent\x18\x0e \x03(\r\x12\x14\n\x0cover_current\x18\x0f \x01(\r\x12\x15\n\rdigital_input\x18\x10 \x01(\r\x12\x14\n\x0c\x61nalog_input\x18\x11 \x03(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.kobuki_ros_interfaces.msg.sensor_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SENSORSTATE']._serialized_start=184
  _globals['_SENSORSTATE']._serialized_end=566
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.autoware_map_msgs.msg import area_info_pb2 as _area_info_pb2
from make87_messages_ros2.jazzy.autoware_map_msgs.msg import point_cloud_map_cell_with_id_pb2 as _point_cloud_map_cell_with_id_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetDifferentialPointCloudMapRequest(_message.Message):
    __slots__ = ("area", "cached_ids")
    AREA_FIELD_NUMBER: _ClassVar[int]
    CACHED_IDS_FIELD_NUMBER: _ClassVar[int]
    area: _area_info_pb2.AreaInfo
    cached_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, area: _Optional[_Union[_area_info_pb2.AreaInfo, _Mapping]] = ..., cached_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class GetDifferentialPointCloudMapResponse(_message.Message):
    __slots__ = ("header", "new_pointcloud_with_ids", "ids_to_remove")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NEW_POINTCLOUD_WITH_IDS_FIELD_NUMBER: _ClassVar[int]
    IDS_TO_REMOVE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    new_pointcloud_with_ids: _containers.RepeatedCompositeFieldContainer[_point_cloud_map_cell_with_id_pb2.PointCloudMapCellWithID]
    ids_to_remove: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., new_pointcloud_with_ids: _Optional[_Iterable[_Union[_point_cloud_map_cell_with_id_pb2.PointCloudMapCellWithID, _Mapping]]] = ..., ids_to_remove: _Optional[_Iterable[str]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BoundingBox3D(_message.Message):
    __slots__ = ("header", "center", "size")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CENTER_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    center: _pose_pb2.Pose
    size: _vector3_pb2.Vector3
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., center: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., size: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ublox_ubx_msgs/msg/ubx_nav_hp_pos_llh.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/humble/ublox_ubx_msgs/msg/ubx_nav_hp_pos_llh.proto\x12.make87_messages_ros2.humble.ublox_ubx_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xfa\x03\n\x0eUBXNavHPPosLLH\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x0f\n\x07version\x18\x03 \x01(\r\x12\x13\n\x0binvalid_lon\x18\x04 \x01(\x08\x12\x13\n\x0binvalid_lat\x18\x05 \x01(\x08\x12\x16\n\x0einvalid_height\x18\x06 \x01(\x08\x12\x14\n\x0cinvalid_hmsl\x18\x07 \x01(\x08\x12\x16\n\x0einvalid_lon_hp\x18\x08 \x01(\x08\x12\x16\n\x0einvalid_lat_hp\x18\t \x01(\x08\x12\x19\n\x11invalid_height_hp\x18\n \x01(\x08\x12\x17\n\x0finvalid_hmsl_hp\x18\x0b \x01(\x08\x12\x0c\n\x04itow\x18\x0c \x01(\r\x12\x0b\n\x03lon\x18\r \x01(\x05\x12\x0b\n\x03lat\x18\x0e \x01(\x05\x12\x0e\n\x06height\x18\x0f \x01(\x05\x12\x0c\n\x04hmsl\x18\x10 \x01(\x05\x12\x0e\n\x06lon_hp\x18\x11 \x01(\x05\x12\x0e\n\x06lat_hp\x18\x12 \x01(\x05\x12\x11\n\theight_hp\x18\x13 \x01(\x05\x12\x0f\n\x07hmsl_hp\x18\x14 \x01(\x05\x12\r\n\x05h_acc\x18\x15 \x01(\r\x12\r\n\x05v_acc\x18\x16 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ublox_ubx_msgs.msg.ubx_nav_hp_pos_llh_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_UBXNAVHPPOSLLH']._serialized_start=214
  _globals['_UBXNAVHPPOSLLH']._serialized_end=720
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/visualization_msgs/msg/interactive_marker_update.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.visualization_msgs.msg import interactive_marker_pb2 as make87__messages__ros2_dot_jazzy_dot_visualization__msgs_dot_msg_dot_interactive__marker__pb2
from make87_messages_ros2.jazzy.visualization_msgs.msg import interactive_marker_pose_pb2 as make87__messages__ros2_dot_jazzy_dot_visualization__msgs_dot_msg_dot_interactive__marker__pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQmake87_messages_ros2/jazzy/visualization_msgs/msg/interactive_marker_update.proto\x12\x31make87_messages_ros2.jazzy.visualization_msgs.msg\x1aJmake87_messages_ros2/jazzy/visualization_msgs/msg/interactive_marker.proto\x1aOmake87_messages_ros2/jazzy/visualization_msgs/msg/interactive_marker_pose.proto\"\x8b\x02\n\x17InteractiveMarkerUpdate\x12\x11\n\tserver_id\x18\x01 \x01(\t\x12\x0f\n\x07seq_num\x18\x02 \x01(\x04\x12\x0c\n\x04type\x18\x03 \x01(\r\x12U\n\x07markers\x18\x04 \x03(\x0b\x32\x44.make87_messages_ros2.jazzy.visualization_msgs.msg.InteractiveMarker\x12W\n\x05poses\x18\x05 \x03(\x0b\x32H.make87_messages_ros2.jazzy.visualization_msgs.msg.InteractiveMarkerPose\x12\x0e\n\x06\x65rases\x18\x06 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.visualization_msgs.msg.interactive_marker_update_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_INTERACTIVEMARKERUPDATE']._serialized_start=294
  _globals['_INTERACTIVEMARKERUPDATE']._serialized_end=561
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ScheduleState(_message.Message):
    __slots__ = ("name", "last_modified", "last_ran", "next_run", "status")
    NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_MODIFIED_FIELD_NUMBER: _ClassVar[int]
    LAST_RAN_FIELD_NUMBER: _ClassVar[int]
    NEXT_RUN_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    name: str
    last_modified: int
    last_ran: int
    next_run: int
    status: int
    def __init__(self, name: _Optional[str] = ..., last_modified: _Optional[int] = ..., last_ran: _Optional[int] = ..., next_run: _Optional[int] = ..., status: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.rolling.sensor_msgs.msg import point_cloud2_pb2 as _point_cloud2_pb2
from make87_messages_ros2.rolling.shape_msgs.msg import mesh_pb2 as _mesh_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ObjectInformation(_message.Message):
    __slots__ = ("name", "ground_truth_mesh", "ground_truth_point_cloud")
    NAME_FIELD_NUMBER: _ClassVar[int]
    GROUND_TRUTH_MESH_FIELD_NUMBER: _ClassVar[int]
    GROUND_TRUTH_POINT_CLOUD_FIELD_NUMBER: _ClassVar[int]
    name: str
    ground_truth_mesh: _mesh_pb2.Mesh
    ground_truth_point_cloud: _point_cloud2_pb2.PointCloud2
    def __init__(self, name: _Optional[str] = ..., ground_truth_mesh: _Optional[_Union[_mesh_pb2.Mesh, _Mapping]] = ..., ground_truth_point_cloud: _Optional[_Union[_point_cloud2_pb2.PointCloud2, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CorStatusInfo(_message.Message):
    __slots__ = ("header", "protocol", "err_status", "msg_used", "correction_id", "msg_type_valid", "msg_sub_type_valid", "msg_input_handle", "msg_encrypted", "msg_decrypted")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_FIELD_NUMBER: _ClassVar[int]
    ERR_STATUS_FIELD_NUMBER: _ClassVar[int]
    MSG_USED_FIELD_NUMBER: _ClassVar[int]
    CORRECTION_ID_FIELD_NUMBER: _ClassVar[int]
    MSG_TYPE_VALID_FIELD_NUMBER: _ClassVar[int]
    MSG_SUB_TYPE_VALID_FIELD_NUMBER: _ClassVar[int]
    MSG_INPUT_HANDLE_FIELD_NUMBER: _ClassVar[int]
    MSG_ENCRYPTED_FIELD_NUMBER: _ClassVar[int]
    MSG_DECRYPTED_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    protocol: int
    err_status: int
    msg_used: int
    correction_id: int
    msg_type_valid: bool
    msg_sub_type_valid: bool
    msg_input_handle: bool
    msg_encrypted: int
    msg_decrypted: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., protocol: _Optional[int] = ..., err_status: _Optional[int] = ..., msg_used: _Optional[int] = ..., correction_id: _Optional[int] = ..., msg_type_valid: bool = ..., msg_sub_type_valid: bool = ..., msg_input_handle: bool = ..., msg_encrypted: _Optional[int] = ..., msg_decrypted: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class RxmRAWXMeas(_message.Message):
    __slots__ = ("pr_mes", "cp_mes", "do_mes", "gnss_id", "sv_id", "reserved0", "freq_id", "locktime", "cno", "pr_stdev", "cp_stdev", "do_stdev", "trk_stat", "reserved1")
    PR_MES_FIELD_NUMBER: _ClassVar[int]
    CP_MES_FIELD_NUMBER: _ClassVar[int]
    DO_MES_FIELD_NUMBER: _ClassVar[int]
    GNSS_ID_FIELD_NUMBER: _ClassVar[int]
    SV_ID_FIELD_NUMBER: _ClassVar[int]
    RESERVED0_FIELD_NUMBER: _ClassVar[int]
    FREQ_ID_FIELD_NUMBER: _ClassVar[int]
    LOCKTIME_FIELD_NUMBER: _ClassVar[int]
    CNO_FIELD_NUMBER: _ClassVar[int]
    PR_STDEV_FIELD_NUMBER: _ClassVar[int]
    CP_STDEV_FIELD_NUMBER: _ClassVar[int]
    DO_STDEV_FIELD_NUMBER: _ClassVar[int]
    TRK_STAT_FIELD_NUMBER: _ClassVar[int]
    RESERVED1_FIELD_NUMBER: _ClassVar[int]
    pr_mes: float
    cp_mes: float
    do_mes: float
    gnss_id: int
    sv_id: int
    reserved0: int
    freq_id: int
    locktime: int
    cno: int
    pr_stdev: int
    cp_stdev: int
    do_stdev: int
    trk_stat: int
    reserved1: int
    def __init__(self, pr_mes: _Optional[float] = ..., cp_mes: _Optional[float] = ..., do_mes: _Optional[float] = ..., gnss_id: _Optional[int] = ..., sv_id: _Optional[int] = ..., reserved0: _Optional[int] = ..., freq_id: _Optional[int] = ..., locktime: _Optional[int] = ..., cno: _Optional[int] = ..., pr_stdev: _Optional[int] = ..., cp_stdev: _Optional[int] = ..., do_stdev: _Optional[int] = ..., trk_stat: _Optional[int] = ..., reserved1: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/grid_map_msgs/msg/grid_map_info.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/jazzy/grid_map_msgs/msg/grid_map_info.proto\x12,make87_messages_ros2.jazzy.grid_map_msgs.msg\x1a\x37make87_messages_ros2/jazzy/geometry_msgs/msg/pose.proto\"\x87\x01\n\x0bGridMapInfo\x12\x12\n\nresolution\x18\x01 \x01(\x01\x12\x10\n\x08length_x\x18\x02 \x01(\x01\x12\x10\n\x08length_y\x18\x03 \x01(\x01\x12@\n\x04pose\x18\x04 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.geometry_msgs.msg.Poseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.grid_map_msgs.msg.grid_map_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GRIDMAPINFO']._serialized_start=172
  _globals['_GRIDMAPINFO']._serialized_end=307
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/qb_device_msgs/msg/info.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/humble/qb_device_msgs/msg/info.proto\x12.make87_messages_ros2.humble.qb_device_msgs.msg\x1a!make87_messages/core/header.proto\"\x9e\x02\n\x04Info\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\n\n\x02id\x18\x02 \x01(\x05\x12\x13\n\x0bserial_port\x18\x03 \x01(\t\x12\x13\n\x0bmax_repeats\x18\x04 \x01(\x05\x12\x15\n\rget_positions\x18\x05 \x01(\x08\x12\x14\n\x0cget_currents\x18\x06 \x01(\x08\x12\x1d\n\x15get_distinct_packages\x18\x07 \x01(\x08\x12\x14\n\x0cset_commands\x18\x08 \x01(\x08\x12\x1a\n\x12set_commands_async\x18\t \x01(\x08\x12\x17\n\x0fposition_limits\x18\n \x03(\x05\x12\x1b\n\x13\x65ncoder_resolutions\x18\x0b \x03(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.qb_device_msgs.msg.info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_INFO']._serialized_start=145
  _globals['_INFO']._serialized_end=431
# @@protoc_insertion_point(module_scope)
